@@ -1,23 +1,13 @@
 /*
- * Copyright 2015-2017 Matthieu Gallien <matthieu_gallien@yahoo.fr>
- *
- * This program is free software: you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 3 of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+   SPDX-FileCopyrightText: 2015 (c) Matthieu Gallien <matthieu_gallien@yahoo.fr>
+
+   SPDX-License-Identifier: LGPL-3.0-or-later
  */
 
 #include "databasetestdata.h"
 
 #include "file/localfilelisting.h"
+#include "elisa_settings.h"
 
 #include "config-upnp-qt.h"
 
@@ -32,8 +22,7 @@
 #include <QDir>
 #include <QFile>
 
-
-#include <QtTest>
+#include <QSignalSpy>
 #include <QTest>
 
 #include <algorithm>
@@ -57,6 +46,7 @@ private Q_SLOTS:
         qRegisterMetaType<QVector<qlonglong>>("QVector<qlonglong>");
         qRegisterMetaType<QHash<qlonglong,int>>("QHash<qlonglong,int>");
         qRegisterMetaType<QList<QUrl>>("QList<QUrl>");
+        Elisa::ElisaConfiguration::instance(QStringLiteral("scanAtStartupFeature"));
     }
 
     void initialTestWithNoTrack()
@@ -87,6 +77,43 @@ private Q_SLOTS:
         QCOMPARE(removedTracksListSpy.count(), 0);
     }
 
+    void initialTestWithEnabledScanOnStartupSetting()
+    {
+        LocalFileListing myListing;
+
+        Elisa::ElisaConfiguration::self()->setDefaults();
+
+        QSignalSpy tracksListSpy(&myListing, &LocalFileListing::tracksList);
+        QSignalSpy askRestoredTracksSpy(&myListing, &LocalFileListing::askRestoredTracks);
+
+        QCOMPARE(tracksListSpy.count(), 0);
+        QCOMPARE(askRestoredTracksSpy.count(), 0);
+
+        myListing.init();
+
+        QCOMPARE(tracksListSpy.count(), 0);
+        QCOMPARE(askRestoredTracksSpy.count(), 1);
+    }
+
+    void initialTestWithDisabledScanOnStartupSetting()
+    {
+        LocalFileListing myListing;
+
+        Elisa::ElisaConfiguration::self()->setDefaults();
+        Elisa::ElisaConfiguration::self()->setScanAtStartup(false);
+
+        QSignalSpy tracksListSpy(&myListing, &LocalFileListing::tracksList);
+        QSignalSpy askRestoredTracksSpy(&myListing, &LocalFileListing::askRestoredTracks);
+
+        QCOMPARE(tracksListSpy.count(), 0);
+        QCOMPARE(askRestoredTracksSpy.count(), 0);
+
+        myListing.init();
+
+        QCOMPARE(tracksListSpy.count(), 0);
+        QCOMPARE(askRestoredTracksSpy.count(), 0);
+    }
+
     void initialTestWithTracks()
     {
         LocalFileListing myListing;
@@ -422,6 +449,8 @@ private Q_SLOTS:
     {
         LocalFileListing myListing;
 
+        Elisa::ElisaConfiguration::self()->setDefaults();
+
         QSignalSpy tracksListSpy(&myListing, &LocalFileListing::tracksList);
         QSignalSpy removedTracksListSpy(&myListing, &LocalFileListing::removedTracksList);
         QSignalSpy modifiedTracksListSpy(&myListing, &LocalFileListing::modifyTracksList);
