@@ -97,6 +97,10 @@ class ELISALIB_EXPORT ElisaApplication : public QObject
                READ initialViewIndex
                NOTIFY initialViewIndexChanged)
 
+    Q_PROPERTY(QString initialFilesViewPath
+               READ initialFilesViewPath
+               NOTIFY initialFilesViewPathChanged)
+
 public:
     explicit ElisaApplication(QObject *parent = nullptr);
 
@@ -139,6 +143,8 @@ public:
 
     int initialViewIndex() const;
 
+    [[nodiscard]] QString initialFilesViewPath() const;
+
 Q_SIGNALS:
 
     void musicManagerChanged();
@@ -175,6 +181,8 @@ Q_SIGNALS:
 
     void initialViewIndexChanged();
 
+    void initialFilesViewPathChanged();
+
 public Q_SLOTS:
 
     void appHelpActivated();
@@ -204,6 +212,8 @@ public:
 
     void setQmlEngine(QQmlEngine *engine);
 
+    KColorSchemeManager *getSchemes();
+
 private Q_SLOTS:
 
     void goBack();
