@@ -24,9 +24,10 @@
 #include "upnpbasictypes.h"
 #endif
 
-#if KF5DBusAddons_FOUND
+#if KFDBusAddons_FOUND
 #include <KDBusService>
 #endif
+#include <KColorSchemeManager>
 
 #include "elisautils.h"
 #include "elisaapplication.h"
@@ -53,18 +54,19 @@
 #include "models/lyricsmodel.h"
 #include "localFileConfiguration/elisaconfigurationdialog.h"
 
-#if KF5FileMetaData_FOUND
+#if KFFileMetaData_FOUND
 #include "embeddedcoverageimageprovider.h"
 #endif
+#include "colorschemepreviewimageprovider.h"
 
-#if KF5KIO_FOUND
+#if KFKIO_FOUND
 #include "models/filebrowsermodel.h"
 #include "models/filebrowserproxymodel.h"
 #endif
 
 #include "audiowrapper.h"
 
-#if Qt5DBus_FOUND
+#if QtDBus_FOUND
 #include "mpris2/mpris2.h"
 #include "mpris2/mediaplayer2player.h"
 #endif
@@ -85,7 +87,7 @@ ElisaQmlTestPlugin::ElisaQmlTestPlugin(QObject *aParent)
 void ElisaQmlTestPlugin::initializeEngine(QQmlEngine *engine, const char *uri)
 {
     QQmlExtensionPlugin::initializeEngine(engine, uri);
-#if KF5FileMetaData_FOUND
+#if KFFileMetaData_FOUND
     engine->addImageProvider(QStringLiteral("cover"), new EmbeddedCoverageImageProvider);
 #endif
 }
@@ -134,7 +136,7 @@ void ElisaQmlTestPlugin::registerTypes(const char *uri)
     qmlRegisterType<GridViewProxyModel>(uri, 1, 0, "GridViewProxyModel");
     qmlRegisterType<LyricsModel>(uri, 1, 0, "LyricsModel");
 
-#if KF5KIO_FOUND
+#if KFKIO_FOUND
     qmlRegisterType<FileBrowserModel>(uri, 1, 0, "FileBrowserModel");
     qmlRegisterType<FileBrowserProxyModel>(uri, 1, 0, "FileBrowserProxyModel");
 #endif
@@ -145,7 +147,7 @@ void ElisaQmlTestPlugin::registerTypes(const char *uri)
     qmlRegisterUncreatableType<QAbstractProxyModel>(uri, 1, 0, "AbstractProxyModel", QStringLiteral("Abstract Qt type"));
     qmlRegisterUncreatableType<DataTypes>(uri, 1, 0, "DataTypes", QStringLiteral("Abstract type not to be used in aml directtly"));
 
-#if Qt5DBus_FOUND
+#if QtDBus_FOUND
     qmlRegisterType<Mpris2>(uri, 1, 0, "Mpris2");
     qRegisterMetaType<MediaPlayer2Player*>();
 #endif
@@ -183,7 +185,6 @@ void ElisaQmlTestPlugin::registerTypes(const char *uri)
     qRegisterMetaType<DataTypes::ColumnsRoles>("DataTypes::ColumnsRoles");
     qRegisterMetaType<ModelDataLoader::TrackDataType>("ModelDataLoader::TrackDataType");
     qRegisterMetaType<TracksListener::TrackDataType>("TracksListener::TrackDataType");
-    qRegisterMetaType<ViewManager::IsTreeModelType>("ViewManager::IsTreeModelType");
     qRegisterMetaType<DataTypes::DataType>("DataTypes::DataType");
 
     qmlRegisterSingletonType<ElisaConfigurationDialog>(uri, 1, 0, "ElisaConfigurationDialog",
@@ -200,20 +201,23 @@ void ElisaQmlTestPlugin::registerTypes(const char *uri)
 
         auto newApplication = std::make_unique<ElisaApplication>();
 
-#if KF5DBusAddons_FOUND
+#if KFDBusAddons_FOUND
         auto *elisaService = new KDBusService(KDBusService::Unique, newApplication.get());
 #endif
 
-#if KF5DBusAddons_FOUND
+#if KFDBusAddons_FOUND
         QObject::connect(elisaService, &KDBusService::activateActionRequested, newApplication.get(), &ElisaApplication::activateActionRequested);
         QObject::connect(elisaService, &KDBusService::activateRequested, newApplication.get(), &ElisaApplication::activateRequested);
         QObject::connect(elisaService, &KDBusService::openRequested, newApplication.get(), &ElisaApplication::openRequested);
 #endif
 
         newApplication->setQmlEngine(engine);
+        engine->addImageProvider(QStringLiteral("colorScheme"), new ColorSchemePreviewImageProvider(newApplication->getSchemes()));
 
         return newApplication.release();
     });
 
     qmlRegisterUncreatableMetaObject(ElisaUtils::staticMetaObject, uri, 1, 0, "ElisaUtils", QStringLiteral("Namespace ElisaUtils"));
 }
+
+#include "moc_elisaqmlplugin.cpp"
