@@ -8,7 +8,6 @@
 
 #include <KLocalizedString>
 
-#include <QDebug>
 
 EditableTrackMetadataModel::EditableTrackMetadataModel(QObject *parent)
     : TrackMetadataModel(parent)
@@ -38,6 +37,9 @@ QVariant EditableTrackMetadataModel::data(const QModelIndex &index, int role) co
             case ElisaUtils::Radio:
                 result = false;
                 break;
+            case ElisaUtils::PlayList:
+                result = false;
+                break;
             case ElisaUtils::Album:
             case ElisaUtils::Artist:
             case ElisaUtils::Composer:
@@ -51,68 +53,29 @@ QVariant EditableTrackMetadataModel::data(const QModelIndex &index, int role) co
             }
             break;
         case DataTypes::ImageUrlRole:
-            result = false;
-            break;
         case DataTypes::ArtistRole:
-            result = false;
-            break;
         case DataTypes::AlbumRole:
-            result = false;
-            break;
         case DataTypes::AlbumArtistRole:
-            result = false;
-            break;
         case DataTypes::TrackNumberRole:
-            result = false;
-            break;
         case DataTypes::DiscNumberRole:
-            result = false;
-            break;
         case DataTypes::RatingRole:
-            result = false;
-            break;
         case DataTypes::GenreRole:
-            result = false;
-            break;
         case DataTypes::LyricistRole:
-            result = false;
-            break;
         case DataTypes::ComposerRole:
-            result = false;
-            break;
         case DataTypes::CommentRole:
-            result = false;
-            break;
         case DataTypes::YearRole:
-            result = false;
-            break;
-        case DataTypes::LastPlayDate:
-            result = true;
-            break;
-        case DataTypes::PlayCounter:
-            result = true;
-            break;
         case DataTypes::LyricsRole:
             result = false;
             break;
+        case DataTypes::LastPlayDate:
+        case DataTypes::PlayCounter:
         case DataTypes::DurationRole:
-            result = true;
-            break;
         case DataTypes::SampleRateRole:
-            result = false;
-            break;
         case DataTypes::BitRateRole:
-            result = false;
-            break;
         case DataTypes::ChannelsRole:
-            result = false;
-            break;
         case DataTypes::FirstPlayDate:
             result = true;
             break;
-        case DataTypes::PlayFrequency:
-            result = true;
-            break;
         case DataTypes::SecondaryTextRole:
         case DataTypes::ShadowForImageRole:
         case DataTypes::ChildModelRole:
@@ -134,6 +97,8 @@ QVariant EditableTrackMetadataModel::data(const QModelIndex &index, int role) co
         case DataTypes::IsDirectoryRole:
         case DataTypes::IsPlayListRole:
         case DataTypes::FilePathRole:
+        case DataTypes::HasChildrenRole:
+        case DataTypes::MultipleImageUrlsRole:
             break;
         }
         break;
@@ -182,13 +147,14 @@ QVariant EditableTrackMetadataModel::data(const QModelIndex &index, int role) co
             case DataTypes::HasEmbeddedCover:
             case DataTypes::FileModificationTime:
             case DataTypes::FirstPlayDate:
-            case DataTypes::PlayFrequency:
             case DataTypes::ElementTypeRole:
             case DataTypes::FullDataRole:
             case DataTypes::IsDirectoryRole:
             case DataTypes::IsPlayListRole:
             case DataTypes::FilePathRole:
             case DataTypes::ResourceRole:
+            case DataTypes::HasChildrenRole:
+            case DataTypes::MultipleImageUrlsRole:
                 result = false;
                 break;
             }
@@ -202,6 +168,7 @@ QVariant EditableTrackMetadataModel::data(const QModelIndex &index, int role) co
         case ElisaUtils::Genre:
         case ElisaUtils::Lyricist:
         case ElisaUtils::Unknown:
+        case ElisaUtils::PlayList:
             result = false;
             break;
         }
@@ -237,6 +204,7 @@ bool EditableTrackMetadataModel::setData(const QModelIndex &index, const QVarian
 
 void EditableTrackMetadataModel::saveData()
 {
+    saveChanges();
     mIsNewRadio = false;
     mIsDirty = false;
     Q_EMIT isDirtyChanged();
@@ -256,6 +224,13 @@ void EditableTrackMetadataModel::saveData()
     Q_EMIT saveTrackModified({newTrackData}, {});
 }
 
+void EditableTrackMetadataModel::resetData()
+{
+    undoChanges();
+    mIsDirty = false;
+    Q_EMIT isDirtyChanged();
+}
+
 void EditableTrackMetadataModel::deleteRadio()
 {
     auto &track = displayedTrackData();
@@ -345,7 +320,7 @@ void EditableTrackMetadataModel::validData()
     }
 
     if (!newValidState) {
-        mErrorMessage = i18nc("Error message when track URL is invalid", "Invalid URL.");
+        mErrorMessage = i18nc("@info:status Error message when track URL is invalid", "Invalid URL.");
         Q_EMIT errorMessageChanged();
     }
 
@@ -355,7 +330,7 @@ void EditableTrackMetadataModel::validData()
         newValidState = newValidState && !titleData.toString().isEmpty();
 
         if (!newValidState) {
-            mErrorMessage = i18nc("Error message when track title is empty", "Empty title.");
+            mErrorMessage = i18nc("@info:status Error message when track title is empty", "Empty title.");
             Q_EMIT errorMessageChanged();
         }
     }
