@@ -18,6 +18,7 @@
 #include <QUrl>
 #include <QAbstractListModel>
 #include <QFutureWatcher>
+#include <QMutex>
 
 class MusicListenersManager;
 
@@ -128,6 +129,10 @@ public Q_SLOTS:
 
 protected:
 
+    void saveChanges();
+
+    void undoChanges();
+
     virtual void fillDataFromTrackData(const TrackMetadataModel::TrackDataType &trackData,
                                        const QList<DataTypes::ColumnsRoles> &fieldsForTrack);
 
@@ -170,7 +175,7 @@ private:
 
     TrackDataType mFullData;
 
-    TrackDataType mTrackData;
+    TrackDataType mDisplayData;
 
     QUrl mCoverImage;
 
@@ -178,7 +183,7 @@ private:
 
     qulonglong mDatabaseId = 0;
 
-    QList<TrackDataType::key_type> mTrackKeys;
+    QList<TrackDataType::key_type> mDisplayKeys;
 
     ModelDataLoader mDataLoader;
 
@@ -186,6 +191,8 @@ private:
 
     FileScanner mFileScanner;
 
+    QMutex mFileScannerMutex;
+
     QFutureWatcher<QString> mLyricsValueWatcher;
 };
 
