@@ -12,7 +12,7 @@
 #include "models/datamodel.h"
 #include "models/gridviewproxymodel.h"
 
-#if KF5KIO_FOUND
+#if KFKIO_FOUND
 #include "models/filebrowsermodel.h"
 #include "models/filebrowserproxymodel.h"
 #endif
@@ -36,15 +36,15 @@ public:
                              ViewManager::GenericDataModel,
                              ElisaUtils::FilterById,
                              ElisaUtils::Track,
-                             Qt::DisplayRole,
-                             {Qt::DisplayRole},
-                             {i18nc("@title:inmenu", "Title")},
+                             DataTypes::TrackNumberRole,
+                             {DataTypes::TrackNumberRole, Qt::DisplayRole},
+                             {i18nc("@title:inmenu", "Track Number"), i18nc("@title:inmenu", "Title")},
                              Qt::AscendingOrder,
-                             {i18nc("@item:inmenu", "A-Z"), i18nc("@item:inmenu", "Z-A")},
+                             {i18nc("@item:inmenu", "Ascending"), i18nc("@item:inmenu", "Descending"),
+                              i18nc("@item:inmenu", "A-Z"), i18nc("@item:inmenu", "Z-A")},
                              ViewManager::SingleAlbum,
                              ViewManager::DiscHeaders,
-                             ViewManager::IsTrack,
-                             ViewManager::IsFlatModel}},
+                             ViewManager::IsTrack}},
         {ElisaUtils::Genre, {{},
                              QUrl{QStringLiteral("image://icon/view-media-artist")},
                              ViewManager::GridView,
@@ -58,8 +58,7 @@ public:
                              {i18nc("@item:inmenu", "A-Z"), i18nc("@item:inmenu", "Z-A")},
                              QUrl{QStringLiteral("image://icon/view-media-artist")},
                              ViewManager::DelegateWithoutSecondaryText,
-                             ViewManager::ViewHideRating,
-                             ViewManager::IsFlatModel}},
+                             ViewManager::ViewHideRating}},
         {ElisaUtils::Artist, {{},
                               QUrl{QStringLiteral("image://icon/view-media-album-cover")},
                               ViewManager::GridView,
@@ -73,8 +72,7 @@ public:
                               {i18nc("@item:inmenu", "A-Z"), i18nc("@item:inmenu", "Z-A"), i18nc("@item:inmenu", "A-Z"), i18nc("@item:inmenu", "Z-A"), i18nc("@item:inmenu", "Oldest First"), i18nc("@item:inmenu", "Newest First")},
                               QUrl{QStringLiteral("image://icon/media-default-album")},
                               ViewManager::DelegateWithSecondaryText,
-                              ViewManager::ViewShowRating,
-                              ViewManager::IsFlatModel}},
+                              ViewManager::ViewShowRating}},
         {ElisaUtils::Container, {{},
                                  QUrl{QStringLiteral("image://icon/folder")},
                                  ViewManager::GridView,
@@ -88,17 +86,16 @@ public:
                                  {i18nc("@item:inmenu", "A-Z"), i18nc("@item:inmenu", "Z-A")},
                                  QUrl{QStringLiteral("image://icon/folder")},
                                  ViewManager::DelegateWithoutSecondaryText,
-                                 ViewManager::ViewHideRating,
-                                 ViewManager::IsFlatModel}},
+                                 ViewManager::ViewHideRating}},
     };
 
     int mViewIndex = -1;
 
     int mInitialIndex = -1;
 
-    QList<ViewParameters> mViewParametersStack = (mViewsListData ? QList<ViewParameters>{mViewsListData->viewParameters(0)} : QList<ViewParameters>{});
+    QString mInitialFilesViewPath = QDir::rootPath();
 
-    ViewParameters mNextViewParameters;
+    QList<ViewParameters> mViewParametersStack = (mViewsListData ? QList<ViewParameters>{mViewsListData->viewParameters(0)} : QList<ViewParameters>{});
 };
 
 ViewManager::ViewManager(QObject *parent)
@@ -122,33 +119,39 @@ ViewsListData *ViewManager::viewsData() const
     return d->mViewsListData;
 }
 
+QString ViewManager::initialFilesViewPath() const
+{
+    return d->mInitialFilesViewPath;
+}
+
 ViewManager::~ViewManager() = default;
 
 void ViewManager::openView(int viewIndex)
 {
     qCDebug(orgKdeElisaViews()) << "ViewManager::openView" << viewIndex << d->mViewParametersStack.size() << d->mViewsListData;
 
-    if (!d->mViewsListData || d->mViewsListData->isEmpty() || !d->mViewsListData->isFullyInitialized()) {
+    if (!d->mViewsListData || d->mViewsListData->isEmpty()) {
         return;
     }
 
+    d->mViewParametersStack.clear();
+
     if (viewIndex < 0 || viewIndex >= d->mViewsListData->count()) {
         viewIndex = 0;
     }
 
-    const auto &viewParameters = d->mViewsListData->viewParameters(viewIndex);
+    auto viewParameters = d->mViewsListData->viewParameters(viewIndex);
 
-    qCDebug(orgKdeElisaViews()) << "ViewManager::openView" << "selected view" << viewIndex;
+    qCDebug(orgKdeElisaViews()) << "ViewManager::openView" << "changing view" << viewIndex;
 
-    if (d->mViewParametersStack.isEmpty() || viewParameters != d->mViewParametersStack.back()) {
-        qCDebug(orgKdeElisaViews()) << "ViewManager::openView" << "changing view";
-        d->mViewIndex = viewIndex;
-        Q_EMIT viewIndexChanged();
+    d->mViewIndex = viewIndex;
+    Q_EMIT viewIndexChanged();
 
-        d->mNextViewParameters = viewParameters;
-        applyFilter(d->mNextViewParameters, viewParameters.mMainTitle, d->mNextViewParameters);
-        openViewFromData(d->mNextViewParameters);
+    applyFilter(viewParameters, viewParameters.mMainTitle, viewParameters);
+    if (viewParameters.mDataType == ElisaUtils::FileName) { // Folder view
+        viewParameters.mDataFilter[DataTypes::FilePathRole] = QUrl::fromLocalFile(d->mInitialFilesViewPath);
     }
+    openViewFromData(viewParameters);
 }
 
 void ViewManager::openChildView(const DataTypes::MusicDataType &fullData)
@@ -167,7 +170,7 @@ void ViewManager::openChildView(const DataTypes::MusicDataType &fullData)
         return;
     }
 
-    if (!d->mViewsListData || d->mViewsListData->isEmpty() || !d->mViewsListData->isFullyInitialized()) {
+    if (!d->mViewsListData || d->mViewsListData->isEmpty()) {
         return;
     }
 
@@ -191,61 +194,32 @@ void ViewManager::openChildView(const DataTypes::MusicDataType &fullData)
 
     applyFilter(nextViewParameters, title, lastView);
 
+    // Prevent the user from clicking the same view other and over again
+    if (this->isSameView(nextViewParameters, lastView)) {
+        return;
+    }
+
     if (dataType == ElisaUtils::Album && nextViewParameters.mDataFilter[DataTypes::IsSingleDiscAlbumRole].toBool())
     {
         nextViewParameters.mAlbumViewStyle = NoDiscHeaders;
     }
 
-    d->mNextViewParameters = nextViewParameters;
-
-    if (lastView.mDataType != dataType) {
-        for(int i = 0; i < d->mViewsListData->count(); ++i) {
-            if (d->mViewsListData->viewParameters(i).mDataType == dataType) {
-                d->mViewIndex = i;
-                Q_EMIT viewIndexChanged();
-
-                nextViewParameters = d->mViewsListData->viewParameters(i);
-                break;
-            }
-        }
-    }
-
     openViewFromData(nextViewParameters);
 }
 
 void ViewManager::openAlbumView(const QString &title, const QString &artist, qulonglong databaseId, const QUrl &albumCoverUrl)
 {
-    if (d->mViewsListData->embeddedCategory() == ElisaUtils::Album) {
-        auto index = d->mViewsListData->indexFromEmbeddedDatabaseId(databaseId);
-
-        if (index == -1) {
-            return;
-        }
-
-        openView(index);
-    } else {
-        openChildView({{DataTypes::ElementTypeRole, ElisaUtils::Album},
-                       {DataTypes::DatabaseIdRole, databaseId},
-                       {DataTypes::TitleRole, title},
-                       {DataTypes::ArtistRole, artist},
-                       {DataTypes::ImageUrlRole, albumCoverUrl},});
-    }
+    openChildView({{DataTypes::ElementTypeRole, ElisaUtils::Album},
+                   {DataTypes::DatabaseIdRole, databaseId},
+                   {DataTypes::TitleRole, title},
+                   {DataTypes::ArtistRole, artist},
+                   {DataTypes::ImageUrlRole, albumCoverUrl},});
 }
 
 void ViewManager::openArtistView(const QString &artist)
 {
-    if (d->mViewsListData->embeddedCategory() == ElisaUtils::Artist) {
-        auto index = d->mViewsListData->indexFromEmbeddedName(artist);
-
-        if (index == -1) {
-            return;
-        }
-
-        openView(index);
-    } else {
-        openChildView({{DataTypes::ElementTypeRole, ElisaUtils::Artist},
-                       {DataTypes::TitleRole, artist},});
-    }
+    openChildView({{DataTypes::ElementTypeRole, ElisaUtils::Artist},
+                   {DataTypes::TitleRole, artist},});
 }
 
 void ViewManager::openNowPlaying()
@@ -253,30 +227,10 @@ void ViewManager::openNowPlaying()
     openView(0);
 }
 
-void ViewManager::viewIsLoaded()
-{
-    qCDebug(orgKdeElisaViews()) << "ViewManager::viewIsLoaded" << d->mViewParametersStack.size()
-                                << d->mViewsListData;
-
-    if (!d->mViewParametersStack.size()) {
-        return;
-    }
-
-    if (d->mNextViewParameters.mIsValid && d->mNextViewParameters != d->mViewParametersStack.back()) {
-        openViewFromData(d->mNextViewParameters);
-    }
-}
-
 void ViewManager::openViewFromData(const ViewParameters &viewParamaters)
 {
     qCDebug(orgKdeElisaViews()) << "ViewManager::openViewFromData" << d->mViewParametersStack.size();
 
-    const auto viewsCountToRemove = d->mViewParametersStack.size() + 1 - viewParamaters.mDepth;
-    for (int i = 0; i < viewsCountToRemove; ++i) {
-        qCDebug(orgKdeElisaViews()) << "ViewManager::openViewFromData" << "pop_back";
-        d->mViewParametersStack.pop_back();
-    }
-
     QAbstractItemModel *newModel = nullptr;
     QAbstractProxyModel *proxyModel = nullptr;
 
@@ -284,7 +238,7 @@ void ViewManager::openViewFromData(const ViewParameters &viewParamaters)
     {
     case FileBrowserModel:
     {
-#if KF5KIO_FOUND
+#if KFKIO_FOUND
         newModel = new ::FileBrowserModel;
         auto *realProxyModel = new FileBrowserProxyModel;
         proxyModel = realProxyModel;
@@ -317,8 +271,7 @@ void ViewManager::openViewFromData(const ViewParameters &viewParamaters)
                                     << viewParamaters.mMainImage << viewParamaters.mDataType
                                     << viewParamaters.mModelType << viewParamaters.mFallbackItemIcon
                                     << viewParamaters.mDataFilter
-                                    << viewParamaters.mViewCanBeRated << viewParamaters.mShowSecondaryTextOnDelegates
-                                    << viewParamaters.mIsTreeModel;
+                                    << viewParamaters.mViewCanBeRated << viewParamaters.mShowSecondaryTextOnDelegates;
 
         auto configurationData = std::make_unique<ViewConfigurationData>(viewParamaters.mFilterType, viewParamaters.mDepth,
                                                                          viewParamaters.mMainTitle, viewParamaters.mSecondaryTitle,
@@ -329,8 +282,7 @@ void ViewManager::openViewFromData(const ViewParameters &viewParamaters)
                                                                          viewParamaters.mSortRoles, viewParamaters.mSortRoleNames,
                                                                          computePreferredSortOrder(viewParamaters.mSortOrder, viewParamaters.mFilterType),
                                                                          viewParamaters.mSortOrderNames,
-                                                                         viewParamaters.mViewCanBeRated, viewParamaters.mShowSecondaryTextOnDelegates,
-                                                                         viewParamaters.mIsTreeModel);
+                                                                         viewParamaters.mViewCanBeRated, viewParamaters.mShowSecondaryTextOnDelegates);
 
         QQmlEngine::setObjectOwnership(configurationData.get(), QQmlEngine::JavaScriptOwnership);
 
@@ -345,8 +297,7 @@ void ViewManager::openViewFromData(const ViewParameters &viewParamaters)
                                     << viewParamaters.mModelType << viewParamaters.mDataType
                                     << viewParamaters.mDataFilter << viewParamaters.mSortRole
                                     << viewParamaters.mSortOrder << viewParamaters.mAlbumCardinality
-                                    << viewParamaters.mAlbumViewStyle << viewParamaters.mRadioSpecificStyle
-                                    << viewParamaters.mIsTreeModel;
+                                    << viewParamaters.mAlbumViewStyle << viewParamaters.mRadioSpecificStyle;
 
         auto configurationData = std::make_unique<ViewConfigurationData>(viewParamaters.mFilterType, viewParamaters.mDepth,
                                                                          viewParamaters.mMainTitle, viewParamaters.mSecondaryTitle,
@@ -357,7 +308,7 @@ void ViewManager::openViewFromData(const ViewParameters &viewParamaters)
                                                                          computePreferredSortOrder(viewParamaters.mSortOrder, viewParamaters.mFilterType),
                                                                          viewParamaters.mSortOrderNames,
                                                                          viewParamaters.mAlbumCardinality, viewParamaters.mAlbumViewStyle,
-                                                                         viewParamaters.mRadioSpecificStyle, viewParamaters.mIsTreeModel);
+                                                                         viewParamaters.mRadioSpecificStyle);
 
         QQmlEngine::setObjectOwnership(configurationData.get(), QQmlEngine::JavaScriptOwnership);
 
@@ -404,11 +355,9 @@ void ViewManager::applyFilter(ViewParameters &nextViewParameters,
 QString ViewManager::buildViewId() const
 {
     const auto &entryTypeMetaEnum = QMetaEnum::fromType<ElisaUtils::PlayListEntryType>();
-    QString viewId;
 
-    for (const auto &oneView : std::as_const(d->mViewParametersStack)) {
-        viewId += QString::fromLatin1(entryTypeMetaEnum.valueToKey(oneView.mDataType)) + QStringLiteral("::");
-    }
+    const auto currView = d->mViewParametersStack.back();
+    const auto viewId = QString::fromLatin1(entryTypeMetaEnum.valueToKey(currView.mDataType));
 
     return viewId;
 }
@@ -417,11 +366,7 @@ QStringList::iterator ViewManager::findViewPreference(QStringList &list, const Q
 {
     auto itViewPreference = list.end();
     for(itViewPreference = list.begin(); itViewPreference != list.end(); ++itViewPreference) {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        auto parts = itViewPreference->splitRef(QStringLiteral("=="));
-#else
         auto parts = QStringView(*itViewPreference).split(QStringLiteral("=="));
-#endif
         if (parts.size() != 2) {
             continue;
         }
@@ -433,15 +378,23 @@ QStringList::iterator ViewManager::findViewPreference(QStringList &list, const Q
     return itViewPreference;
 }
 
-Qt::SortOrder ViewManager::computePreferredSortOrder(Qt::SortOrder initialValue, ElisaUtils::FilterType filterType) const
+bool ViewManager::viewHasDefaultSortRole(const ElisaUtils::FilterType filterType) const
 {
     switch (filterType)
     {
     case ElisaUtils::FilterByRecentlyPlayed:
     case ElisaUtils::FilterByFrequentlyPlayed:
-        return Qt::DescendingOrder;
+    case ElisaUtils::FilterById: // Tracks in album view
+        return true;
     default:
-        break;
+        return false;
+    }
+}
+
+Qt::SortOrder ViewManager::computePreferredSortOrder(Qt::SortOrder initialValue, ElisaUtils::FilterType filterType) const
+{
+    if (viewHasDefaultSortRole(filterType)) {
+        return initialValue;
     }
 
     auto currentSortOrderPreferences = Elisa::ElisaConfiguration::sortOrderPreferences();
@@ -449,11 +402,7 @@ Qt::SortOrder ViewManager::computePreferredSortOrder(Qt::SortOrder initialValue,
     auto itViewPreference = findViewPreference(currentSortOrderPreferences, viewId);
 
     if (itViewPreference != currentSortOrderPreferences.end()) {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        auto result = itViewPreference->splitRef(QStringLiteral("=="));
-#else
         auto result = QStringView(*itViewPreference).split(QStringLiteral("=="));
-#endif
         if (result.size() == 2) {
             const auto &sortOrderMetaEnum = QMetaEnum::fromType<Qt::SortOrder>();
             bool conversionOk;
@@ -469,14 +418,8 @@ Qt::SortOrder ViewManager::computePreferredSortOrder(Qt::SortOrder initialValue,
 
 int ViewManager::computePreferredSortRole(int initialValue, ElisaUtils::FilterType filterType) const
 {
-    switch (filterType)
-    {
-    case ElisaUtils::FilterByRecentlyPlayed:
-        return DataTypes::LastPlayDate;
-    case ElisaUtils::FilterByFrequentlyPlayed:
-        return DataTypes::PlayCounter;
-    default:
-        break;
+    if (viewHasDefaultSortRole(filterType)) {
+        return initialValue;
     }
 
     auto currentSortRolePreferences = Elisa::ElisaConfiguration::sortRolePreferences();
@@ -484,11 +427,7 @@ int ViewManager::computePreferredSortRole(int initialValue, ElisaUtils::FilterTy
     auto itViewPreference = findViewPreference(currentSortRolePreferences, viewId);
 
     if (itViewPreference != currentSortRolePreferences.end()) {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        auto result = itViewPreference->splitRef(QStringLiteral("=="));
-#else
         auto result = QStringView(*itViewPreference).split(QStringLiteral("=="));
-#endif
         if (result.size() == 2) {
             const auto &sortRoleMetaEnum = QMetaEnum::fromType<DataTypes::ColumnsRoles>();
             bool conversionOk;
@@ -515,7 +454,6 @@ void ViewManager::goBack()
 
     if (d->mViewParametersStack.size() > 1) {
         d->mViewParametersStack.pop_back();
-        d->mNextViewParameters = {};
     }
 
     qCDebug(orgKdeElisaViews()) << "ViewManager::goBack" << d->mViewParametersStack.size();
@@ -534,14 +472,9 @@ void ViewManager::setViewsData(ViewsListData *viewsData)
         d->mViewIndex = d->mInitialIndex;
     }
 
-    if (d->mViewsListData && d->mViewIndex >= 0 && d->mViewIndex < d->mViewsListData->count() && d->mViewsListData->isFullyInitialized()) {
+    if (d->mViewsListData && d->mViewIndex >= 0 && d->mViewIndex < d->mViewsListData->count()) {
         openView(d->mViewIndex);
     }
-
-    if (d->mViewsListData) {
-        connect(d->mViewsListData, &ViewsListData::isFullyInitializedChanged,
-                this, &ViewManager::openInitialView);
-    }
 }
 
 void ViewManager::setInitialIndex(int newIndex)
@@ -557,11 +490,21 @@ void ViewManager::setInitialIndex(int newIndex)
         d->mViewIndex = d->mInitialIndex;
     }
 
-    if (d->mViewsListData && d->mViewIndex >= 0 && d->mViewIndex < d->mViewsListData->count() && d->mViewsListData->isFullyInitialized()) {
+    if (d->mViewsListData && d->mViewIndex >= 0 && d->mViewIndex < d->mViewsListData->count()) {
         openView(d->mViewIndex);
     }
 }
 
+void ViewManager::setInitialFilesViewPath(const QString &initialPath)
+{
+    if (d->mInitialFilesViewPath == initialPath) {
+        return;
+    }
+
+    d->mInitialFilesViewPath = initialPath;
+    Q_EMIT initialFilesViewPathChanged();
+}
+
 void ViewManager::openInitialView()
 {
     openView(d->mInitialIndex);
@@ -569,6 +512,10 @@ void ViewManager::openInitialView()
 
 void ViewManager::sortOrderChanged(Qt::SortOrder sortOrder)
 {
+    if (viewHasDefaultSortRole(d->mViewParametersStack.back().mFilterType)) {
+        return;
+    }
+
     auto currentSortOrderPreferences = Elisa::ElisaConfiguration::sortOrderPreferences();
 
     auto viewId = buildViewId();
@@ -593,6 +540,10 @@ void ViewManager::sortOrderChanged(Qt::SortOrder sortOrder)
 
 void ViewManager::sortRoleChanged(int sortRole)
 {
+    if (viewHasDefaultSortRole(d->mViewParametersStack.back().mFilterType)) {
+        return;
+    }
+
     auto currentSortRolePreferences = Elisa::ElisaConfiguration::sortRolePreferences();
 
     auto viewId = buildViewId();
@@ -615,5 +566,25 @@ void ViewManager::sortRoleChanged(int sortRole)
     Elisa::ElisaConfiguration::self()->save();
 }
 
+bool ViewManager::isSameView(const ViewParameters &currentView, const ViewParameters &otherView) const {
+    if (currentView.mDataType != otherView.mDataType) {
+        return false;
+    }
+
+    // Best case scenario is matching up database ids
+    if (currentView.mDataFilter.hasDatabaseId() && otherView.mDataFilter.hasDatabaseId()) {
+        return currentView.mDataFilter.databaseId() == otherView.mDataFilter.databaseId();
+    }
+
+    // Unfortunately we don't have access to database ids for most of these types, so handle specific types differently.
+    switch (currentView.mDataType) {
+        case ElisaUtils::PlayListEntryType::Album:
+        case ElisaUtils::PlayListEntryType::Artist:
+            return currentView.mMainTitle == otherView.mMainTitle;
+        default:
+            return false;
+    }
+}
+
 
 #include "moc_viewmanager.cpp"
